@@ -2,7 +2,7 @@ import math
 from decimal import Decimal
 
 
-def get_angle_adj_hyp(adj: Decimal, hyp: Decimal, unit: str = "deg") -> Decimal:
+def get_angle_adj_hyp(adj: float, hyp: float, unit: str = "deg") -> Decimal:
     """
     Get angle between adjacent and hypothenuse of a right triangle.
     :param adj: length of the adjacent (ankathete)
@@ -10,14 +10,14 @@ def get_angle_adj_hyp(adj: Decimal, hyp: Decimal, unit: str = "deg") -> Decimal:
     :param unit: "deg" or "rad"
     :return:
     """
-    cos_alpha = adj / hyp
+    cos_alpha = Decimal(adj / hyp)
     angle = Decimal(math.acos(cos_alpha))
     if unit.lower() == "deg":
         angle = Decimal(math.degrees(angle))
     return angle
 
 
-def get_angle_opp_hyp(opp: Decimal, hyp: Decimal, unit: str = "deg") -> Decimal:
+def get_angle_opp_hyp(opp: float, hyp: float, unit: str = "deg") -> Decimal:
     """
     Get angle between opposite and hypothenuse of a right triangle.
     :param opp: length of the opposite (Gegenkathete)
@@ -25,14 +25,14 @@ def get_angle_opp_hyp(opp: Decimal, hyp: Decimal, unit: str = "deg") -> Decimal:
     :param unit: "deg" or "rad"
     :return:
     """
-    sin_alpha = opp / hyp
+    sin_alpha = Decimal(opp / hyp)
     angle = Decimal(math.asin(sin_alpha))
     if unit.lower() == "deg":
         angle = Decimal(math.degrees(angle))
     return angle
 
 
-def get_angle_opp_adj(opp: Decimal, adj: Decimal, unit: str = "deg") -> Decimal:
+def get_angle_opp_adj(opp: float, adj: float, unit: str = "deg") -> Decimal:
     """
     Get angle between opposite and adjacent of a right triangle.
     :param opp: length of the opposite (Gegenkathete)
@@ -40,9 +40,8 @@ def get_angle_opp_adj(opp: Decimal, adj: Decimal, unit: str = "deg") -> Decimal:
     :param unit: "deg" or "rad"
     :return:
     """
-    tan_alpha = opp / adj
-    angle = Decimal(math.asin(tan_alpha))
+    tan_alpha = Decimal(opp / adj)
+    angle = Decimal(math.atan(tan_alpha))
     if unit.lower() == "deg":
         angle = Decimal(math.degrees(angle))
     return angle
-
